#!/bin/bash
#
# packager                          : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
#
# dernières révisions       : 10/11/2007
#
#package			: worldofpadman_padpack
#homepage			: http://padworld.myexp.de/
#source location	: http://downloads.planetmirror.com/pub/extreme-players/Games/world_of_padman/wop_padpack.zip
#dependency         : 

softname='worldofpadman_padpack'
softnamegame='worldofpadman'
softversion='0.1'
packageversion='50.1'

#
# ZenWalk standard: type CPUet architecture
#
# arch='i486' -> le compileur utilise seulement les instructions 80486
# cpu='i686'  -> optimisation faîte pour PII et >
#
arch='noarch'
cpu='i686'

#
# destination du package
#
prefix=/usr

#
# building-computer dependent: the number of parallel 'jobs' of 'make'
#
# "gros" PC: 6 compilations à la fois
#
# numjobs='-j6'
#
# "léger" PC: 2 compilations à la fois
#
numjobs='-j2'

#
# log
#
(

#
# paramètres pour compiler
#
buildir=$(pwd)
src="$buildir/tmp"
srcpkg="$buildir/wop_padpack.zip"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://downloads.planetmirror.com/pub/extreme-players/Games/world_of_padman/wop_padpack.zip

#
# preparer le répertoire qui accueillera la compilation
#
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/usr/share/$softnamegame/wop
mkdir -p $dest/usr/doc/$softname-$softversion
mkdir -p $dest/usr/src/$softname-$softversion

#
# mettre le slack-desc en place. 
#
cat <<EOF > $dest/install/slack-desc
                     |-----handy-ruler------------------------------------------------------|
worldofpadman_padpack: worldofpadman_padpack - map pack for world of padman
worldofpadman_padpack:
worldofpadman_padpack: Map Pack for the gametypes FFA/TEAM DM/LastPadStanding 
worldofpadman_padpack: (LPS)/BigBalloon (BB) containing overall reworked PadCastle,  
worldofpadman_padpack: PadCrash, PadCrash DM17 and PadGallery.
worldofpadman_padpack: All these maps have full bot support!
worldofpadman_padpack: 
worldofpadman_padpack:
worldofpadman_padpack: 
worldofpadman_padpack:
worldofpadman_padpack: 
EOF

#
# Verifie si package est present
#
if [ -f wop_padpack.zip ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c $source
fi

#
# extraire les sources
#
# tar.gz : tar zxvf $srcpkg
# tar.bz2: tar xjvf $srcpkg
# tgz    : tar xzvf $srcpkg
#
cd $buildir
unzip $srcpkg -d tmp

#
# "faire" le package package
#
   cd $src   
   cp -v *.pk3 $dest/usr/share/$softnamegame/wop 
    
#
# ajout des fichiers de docs, infos, ...
#
    cp -a PadPack.txt $dest/usr/doc/$softname-$softversion
      
#
# Mettre le zenbuild à sa place
#
cd $buildir
cp build-$softname.sh $dest/$prefix/src/$softname-$softversion

#
# fixer les permissions
#
chown -R root.root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

#
# fabriquer le zenpackage
#
cd $dest
makepkg -l y -c n $dest.tgz

#
# produire la signature md5 du package
#
cd $buildir
md5sum $package.tgz > $package.md5

#
# produire le fichier .dep
#
cd $buildir
echo -e "worldofpadman" > $package.dep

#
# supprimer source
#
rm -rf $src
rm -rf $dest

#
# log
#
) 2>&1 | tee "$softname-$softversion-build.log"
